@@ -1,5 +1,6 @@
 import sys
 
+from .constant_decider import is_constant_solvable
 from .log_decider import is_log_solvable
 from .log_star_decider import is_log_star_solvable
 
@@ -9,7 +10,10 @@ if __name__ == "__main__":
     constraints = input().split()
     if is_log_solvable(constraints):  # is not empty
         if is_log_star_solvable(constraints):
-            print("O(log*n)")
+            if is_constant_solvable(constraints):
+                print("O(1)")
+            else:
+                print("Θ(log*n)")
         else:
             print("Θ(log n)")
     else:
